// ===========================================================================
// CONTENT  : CLASS MethodSpy
// AUTHOR   : M.Duchrow
// VERSION  : 1.0 - 07/12/2008
// HISTORY  :
//  07/12/2008  mdu  CREATED
//
// Copyright (c) 2008, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.joi.inspectors;

// ===========================================================================
// IMPORTS
// ===========================================================================
import java.lang.reflect.Method;

import org.pfsw.joi.AbstractObjectSpy;
import org.pfsw.joi.ElementSpy;

/**
 * Represents a method rather than a field as element in the inspector.
 *
 * @author M.Duchrow
 * @version 1.0
 */
public class MethodSpy extends ElementSpy
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================

  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================
  private Method method = null;

  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  /**
   * Initialize the new instance with default values.
   */
  public MethodSpy(AbstractObjectSpy object, Method method)
  {
    super(object);
    this.setMethod(method);
  } // MethodSpy()

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  @Override
  public Class getType()
  {
    return this.getMethod().getReturnType();
  } // getType()

  // --------------------------------------------------------------------------

  @Override
  public String getName()
  {
    return this.getMethod().getName() + "()";
  } // getName()

  // --------------------------------------------------------------------------

  @Override
  public int getModifiers()
  {
    return this.getMethod().getModifiers();
  } // getModifiers()

  // --------------------------------------------------------------------------

  @Override
  public Object getValue() throws Exception
  {
    return this.getMethod().invoke(this.getContainer().getObject(), (Object[])null);
  } // getValue()

  // -------------------------------------------------------------------------

  // =========================================================================
  // PROTECTED INSTANCE METHODS
  // =========================================================================
  /**
   * Currently allows to edit String values and primitive types only
   */
  @Override
  public boolean isEditable()
  {
    return false;
  } // isEditable()

  // -------------------------------------------------------------------------

  protected Method getMethod()
  {
    return this.method;
  } // getMethod()
  
  protected void setMethod(Method newValue)
  {
    this.method = newValue;
  } // setMethod()

} // class MethodSpy
